@@ -49,6 +49,8 @@ type Logger struct {
 	childThreadEmitLogs AtomicBool
 	muted               int32
 	kubeContext         string
+	// Map to store cancel functions per each job.
+	jobLoggerCancelers sync.Map
 }
 
 type AtomicBool struct{ flag int32 }
@@ -127,7 +129,9 @@ func (l *Logger) Start(ctx context.Context, out io.Writer) error {
 				return
 			case info := <-l.tracker.Notifier():
 				id, namespace := info[0], info[1]
-				go l.streamLogsFromKubernetesJob(ctx, id, namespace, false)
+				jobLogCancelCtx, jobLogCancel := context.WithCancel(ctx)
+				l.jobLoggerCancelers.Store(id, jobLogCancel)
+				go l.streamLogsFromKubernetesJob(jobLogCancelCtx, id, namespace, false)
 			}
 		}
 	}()
@@ -156,7 +160,7 @@ func (l *Logger) streamLogsFromKubernetesJob(ctx context.Context, id, namespace
 				}
 			}
 			var podName string
-			w, err := clientset.CoreV1().Pods(namespace).Watch(context.TODO(),
+			w, err := clientset.CoreV1().Pods(namespace).Watch(ctx,
 				metav1.ListOptions{
 					LabelSelector: labels.Set(map[string]string{"job-name": id, "skaffold.dev/run-id": l.labeller.GetRunID()}).String(),
 				})
@@ -191,7 +195,7 @@ func (l *Logger) streamLogsFromKubernetesJob(ctx context.Context, id, namespace
 
 			// Stream the logs
 			req := clientset.CoreV1().Pods(namespace).GetLogs(podName, podLogOptions)
-			podLogs, err := req.Stream(context.TODO())
+			podLogs, err := req.Stream(ctx)
 			if err != nil {
 				return false, nil
 			}
@@ -219,6 +223,7 @@ func (l *Logger) Stop() {
 		return
 	}
 	l.childThreadEmitLogs.Set(false)
+	l.wg.Wait()
 
 	l.hadLogsOutput.Range(func(key, value interface{}) bool {
 		if !value.(bool) {
@@ -262,3 +267,9 @@ func (l *Logger) IsMuted() bool {
 func (l *Logger) SetSince(time.Time) {
 	// we always create a new Job on Verify, so this is a noop.
 }
+
+func (l *Logger) CancelJobLogger(jobID string) {
+	if cancelJobLogger, found := l.jobLoggerCancelers.Load(jobID); found {
+		cancelJobLogger.(context.CancelFunc)()
+	}
+}
